@@ -1,10 +1,10 @@
-# Copyright (c) 2002 the World Wide Web Consortium :
+# Copyright (c) 2002-2003 the World Wide Web Consortium :
 #       Keio University,
-#       Institut National de Recherche en Informatique et Automatique,
+#       European Research Consortium for Informatics and Mathematics
 #       Massachusetts Institute of Technology.
 # written by Olivier Thereaux <ot@w3.org> for W3C
 #
-# $Id: Mail.pm,v 1.1 2003/05/07 02:53:20 ot Exp $
+# $Id: Mail.pm,v 1.10 2004/09/10 00:41:24 ot Exp $
 
 package W3C::LogValidator::Output::Mail;
 use strict;
@@ -15,7 +15,7 @@ our @ISA = qw(Exporter);
 our %EXPORT_TAGS = ( 'all' => [ qw() ] );
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT = qw();
-our $VERSION = '0.1';
+our $VERSION = sprintf "%d.%03d",q$Revision: 1.10 $ =~ /(\d+)\.(\d+)/;
 
 
 ###########################
@@ -42,34 +42,10 @@ sub output
 	my %results;
 	my $outputstr ="";
 	if (@_) {%results = %{(shift)}}
-	$outputstr= "
-************************************************************************
-Results for module ".$results{'name'}."
-************************************************************************\n";
-	$outputstr= $outputstr.$results{"intro"}."\n\n" if ($results{"intro"});
-	my @thead = @{$results{"thead"}};
-	while (@thead)
-	{
-		my $header = shift (@thead);	
-		$outputstr= $outputstr."$header   ";
-	}
-	$outputstr= $outputstr."\n";
-	my @trows = @{$results{"trows"}};
-	while (@trows)
-	{
-		my @row=@{shift (@trows)};
-		my $tcell;
-		while (@row)
-		{
-			$tcell= shift (@row);	
-			chomp $tcell;
-			$outputstr= $outputstr."$tcell   ";
-		}
-		$outputstr= $outputstr."\n";
-	}
-	$outputstr= $outputstr."\n";
-	$outputstr= $outputstr.$results{"outro"}."
-************************************************************************\n\n" if ($results{"outro"});
+	use W3C::LogValidator::Output::Raw;
+	$outputstr = W3C::LogValidator::Output::Raw->output(\%results);
+	print $outputstr if ($verbose >2 ); # debug
+
 	return $outputstr;	
 }
 
@@ -82,20 +58,35 @@ sub finish
         {
                 my $result_string = shift;
 		my ($sec,$min,$hour,$day,$mon,$year,$wday,$yday) = gmtime(time);
+	        $hour = sprintf ( "%02d", $hour);
+		$min = sprintf ( "%02d", $min);
 		$mon ++; # weird 'feature': months run 0-11; days run 1-31 :-(
 		my $date = ($year+1900) .'-'. ($mon>9 ? $mon:"0$mon") .'-'. ($day>9 ? $day:"0$day");
 
 		if (defined $config{"ServerAdmin"})
+		# we have someone to send the mail to
 		{
+			my $mail_subject = "Logvalidator results";
+			if (defined $config{"Title"})
+			{
+				$mail_subject = $config{"Title"};
+			}
+			$mail_subject = $mail_subject." ($date  $hour:$min GMT)";
 			my $add = $config{"ServerAdmin"};
+			my $mail_from = $add;
+			if (defined $config{"MailFrom"})
+			{
+				$mail_from = $config{"MailFrom"};
+			}
 			use Mail::Sendmail;
 			my %mail = (To      => $add,
-			From    =>  "LogValidator <$add>",
-			Subject => "Logvalidator results : $date at $hour:$min GMT",
+			From    =>  "LogValidator <$mail_from>",
+			Subject => "$mail_subject",
 			'X-Mailer' => "Mail::Sendmail version $Mail::Sendmail::VERSION",
 			Message => $result_string );
 			print "Sending Mail to $add...\n" if ($verbose >1 );
 			Mail::Sendmail::sendmail(%mail) or print STDERR $Mail::Sendmail::error;
+			if ($verbose >1 ) { print "OK Mail::Sendmail log:\n", $Mail::Sendmail::log, "\n";}
 		}
 		else { print $result_string; }
 	}
@@ -113,9 +104,6 @@ __END__
 
 W3C::LogValidator::Output::Mail - e-mail output module for the Log Validator
 
-=head1 SYNOPSIS
-
-
 =head1 DESCRIPTION
 
 This module is part of the W3C::LogValidator suite, and sends the results
